#### ENVIRONMENT SPECIFICATIONS
* Working OS: Ubuntu 16.04 LTS
* Python version: 3.5.2 (pre-installed)
* Git version: 2.7.4
* pip version: 8.1.1
* virtualenv version: 15.2.0
* Django version: 2.0.4
* MySQL server version: 5.7.22
---

#### DOWNLOADING THE PROJECT & SETTING UP THE ENVIRONMENT
(A) install pip3 (`pip3 --version` to see if it is already installed):
    
    sudo apt-get install python3-pip
(B) install virtualenv (`virtualenv --version` to see if it is already installed):
    
    pip3 install virtualenv
(C\) install and configure Git [sources:
&nbsp; &nbsp; &nbsp; &nbsp;-- "How To Install Git with Apt" and "How To Set Up Git" sections of https://www.digitalocean.com/community/tutorials/how-to-install-git-on-ubuntu-16-04
&nbsp; &nbsp; &nbsp; &nbsp;-- https://www.tutorialspoint.com/git/git_environment.htm
&nbsp; &nbsp; &nbsp; &nbsp;]:
&nbsp; &nbsp; &nbsp; &nbsp;(1) install Git (`git --version` to see if it is already installed):

    sudo apt-get install git
&nbsp; &nbsp; &nbsp; &nbsp;(2) set the Git "name" and "email" global parameters (`git config --list` to see if they have already been set):

    git config --global user.name "YOUR_NAME"
    git config --global user.email "YOUR_EMAIL"
(D) create a local instance of the remote repository (userbase):
&nbsp; &nbsp; &nbsp; &nbsp;(1) navigate to Desktop:

    cd ~/Desktop
&nbsp; &nbsp; &nbsp; &nbsp;(2) clone the repository to create the corresponding instance locally:

    git clone https://git.softlab.ntua.gr/giorgkazelidis/userbase.git
&nbsp; &nbsp; &nbsp; &nbsp;(3) navigate to the local instance:

    cd userbase
(E) install Django and MySQL inside the local instance using virtualenv with Python 3 [sources:
&nbsp; &nbsp; &nbsp; &nbsp;-- steps 2 and 3 of https://help.dreamhost.com/hc/en-us/articles/215317948-How-to-install-Django-using-virtualenv
&nbsp; &nbsp; &nbsp; &nbsp;-- step 3 of https://www.digitalocean.com/community/tutorials/how-to-create-a-django-app-and-connect-it-to-a-database
&nbsp; &nbsp; &nbsp; &nbsp;-- end of section http://docs.python-guide.org/en/latest/dev/virtualenvs/#lower-level-virtualenv
&nbsp; &nbsp; &nbsp; &nbsp;-- https://www.digitalocean.com/community/tutorials/how-to-install-mysql-on-ubuntu-16-04
&nbsp; &nbsp; &nbsp; &nbsp;-- "Create a MySQL Database" section of http://www.marinamele.com/taskbuster-django-tutorial/install-and-configure-mysql-for-django
&nbsp; &nbsp; &nbsp; &nbsp;-- https://www.tutorialspoint.com/django/django_admin_interface.htm
&nbsp; &nbsp; &nbsp; &nbsp;]:
&nbsp; &nbsp; &nbsp; &nbsp;(1) specify the full file path (/usr/bin/python3) to the installed Python version:

    which python3
&nbsp; &nbsp; &nbsp; &nbsp;(2) create the virtual environment (venv) and specify the desired Python version to be used: 

    virtualenv ~/Desktop/userbase/venv -p /usr/bin/python3
&nbsp; &nbsp; &nbsp; &nbsp;(3) activate the virtual environment:

    source venv/bin/activate
&nbsp; &nbsp; &nbsp; &nbsp;(4) install necessary Python and MySQL development headers and libraries (if you have not already done so):

    sudo apt-get install python3-dev libmysqlclient-dev
&nbsp; &nbsp; &nbsp; &nbsp;(5) install appropriate versions of virtual-environment-specific packages:

    pip install -r requirements.txt
&nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp;ALTERNATIVELY, you could install the packages (Django and MySQL Database Connector - mysqlclient) individually by typing the following:

    pip install Django==2.0.4
    pip install mysqlclient
&nbsp; &nbsp; &nbsp; &nbsp;(6) install MySQL server (`mysql --version` to see if it is already installed):
&nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; * WARNING: while installing MySQL server, you will be asked to set the password for the root user.

    sudo apt-get install mysql-server
    mysql_secure_installation
&nbsp; &nbsp; &nbsp; &nbsp;(7) use the password that was set for the root user during MySQL server installation as the 'PASSWORD' value of the 'default' dictionary of the DATABASES dictionary in **~/Desktop/userbase/myprj/myprj/settings.py**
&nbsp; &nbsp; &nbsp; &nbsp;(8) if you have not created the project database (usermergeDB) yet, open MySQL console with root privileges (you should provide the password that was set for the root user during MySQL server installation), create the project database and exit MySQL console:

    mysql -u root -p (ALTERNATIVELY: python manage.py dbshell)
    CREATE DATABASE usermergeDB;
    EXIT;
&nbsp; &nbsp; &nbsp; &nbsp;(9) initiate the database:
    
    python manage.py migrate
&nbsp; &nbsp; &nbsp; &nbsp;(10) deactivate the virtual environment:
    
    deactivate
---

#### UPDATING THE PROJECT
Provided you have already downloaded the (source code of the) project (that is, you have followed the steps of the "DOWNLOADING THE PROJECT & SETTING UP THE ENVIRONMENT" section above), the recommended steps to update the (source code of the) project are:
&nbsp; &nbsp; &nbsp; &nbsp;(1) delete the local instance of the remote repository (userbase) as well as the virtual environment:

    rm -rf ~/Desktop/userbase
&nbsp; &nbsp; &nbsp; &nbsp;(2) follow steps (D) and (E) of the "DOWNLOADING THE PROJECT & SETTING UP THE ENVIRONMENT" section above

---
#### RUNNING THE PROJECT (INSIDE THE VIRTUAL ENVIRONMENT):
(A) activate the virtual environment: 

    cd ~/Desktop/userbase
    source venv/bin/activate
(B) navigate to the project directory (myprj):
    
    cd myprj
(C\) start the Django development server (at http://127.0.0.1:8000/):
    
    python manage.py runserver
(D) navigate to http://127.0.0.1:8000/ via web browser to run the project

---
#### STOPPING THE PROJECT (AND EXITING THE VIRTUAL ENVIRONMENT):
(A) stop the Django development server (running at http://127.0.0.1:8000/):
&nbsp; &nbsp; &nbsp; &nbsp;-- return to the terminal where you have run `python manage.py runserver` and press "Ctrl-C"
(B) deactivate the virtual environment:
    
    deactivate
